diff mbox series

[API-NEXT,v1,1/1] api: packet: change argument to enable for l3 and l4 chsums

Message ID 1509109205-18585-2-git-send-email-odpbot@yandex.ru
State Superseded
Headers show
Series [API-NEXT,v1,1/1] api: packet: change argument to enable for l3 and l4 chsums | expand

Commit Message

Github ODP bot Oct. 27, 2017, 1 p.m. UTC
From: Maxim Uvarov <maxim.uvarov@linaro.org>


function name already has l3 and l4 layer, argument enable
is more clean here.

Signed-off-by: Maxim Uvarov <maxim.uvarov@linaro.org>

---
/** Email created from pull request 264 (muvarov:api-next_chsum)
 ** https://github.com/Linaro/odp/pull/264
 ** Patch: https://github.com/Linaro/odp/pull/264.patch
 ** Base sha: 201a96f9bbcbabd904362ba05a179c72689a578e
 ** Merge commit sha: 4be749425509c18b783489c7df355623f89c395e
 **/
 include/odp/api/spec/packet.h | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
diff mbox series

Patch

diff --git a/include/odp/api/spec/packet.h b/include/odp/api/spec/packet.h
index 62ecf70e1..be7e7d6c7 100644
--- a/include/odp/api/spec/packet.h
+++ b/include/odp/api/spec/packet.h
@@ -1414,10 +1414,10 @@  odp_packet_chksum_status_t odp_packet_l4_chksum_status(odp_packet_t pkt);
  * the relevant pktout chksum bit set in the pktio capability.
  *
  * @param pkt     Packet handle
  * @param l3      0: do not insert L3 checksum
  *                1: insert L3 checksum
  */
-void odp_packet_l3_chksum_insert(odp_packet_t pkt, int l3);
+void odp_packet_l3_chksum_insert(odp_packet_t pkt, int enable);
 
 /**
  * Layer 4 checksum insertion override
@@ -1431,10 +1431,10 @@  void odp_packet_l3_chksum_insert(odp_packet_t pkt, int l3);
  * the relevant pktout chksum bit set in the pktio capability.
  *
  * @param pkt     Packet handle
  * @param l4      0: do not insert L4 checksum
  *                1: insert L4 checksum
  */
-void odp_packet_l4_chksum_insert(odp_packet_t pkt, int l4);
+void odp_packet_l4_chksum_insert(odp_packet_t pkt, int enable);
 
 /**
  * Packet flow hash value
@@ -1414,10 +1414,10 @@  odp_packet_chksum_status_t odp_packet_l4_chksum_status(odp_packet_t pkt);
  *
  * @param pkt     Packet handle
- * @param l3      0: do not insert L3 checksum
+ * @param enable  0: do not insert L3 checksum
  *                1: insert L3 checksum
  */
@@ -1431,10 +1431,10 @@  void odp_packet_l3_chksum_insert(odp_packet_t pkt, int l3);
  *
  * @param pkt     Packet handle
- * @param l4      0: do not insert L4 checksum
+ * @param enable  0: do not insert L4 checksum
  *                1: insert L4 checksum
  */